@@ -33,9 +33,10 @@
 #  define KAUTH_DEPRECATED_NO_EXPORT KAUTH_NO_EXPORT KAUTH_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KAUTH_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KAUTH_NO_DEPRECATED
+#    define KAUTH_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
